#include "fasta.h"
#include <sstream>
#include <iostream>
#include <stdexcept>

using std::cerr;
using std::cout;
using std::endl;
using std::string;
using std::istringstream;
typedef bioinfo::fasta<std::string> fasta;
typedef bioinfo::fasta_seq<std::string> fasta_seq;


void
usage(const string&);

int 
main(int argc, char** argv) {
  if( argc < 7 ) {
    cerr<<"Expecting 6 arguments:"<<endl;
    usage(argv[0]);
    return 0;
  }
  string* header = new string(argv[1]);
  const string db_header = argv[2];
  const string coords = string(argv[3]) + string(" ") + string(argv[4]);
  istringstream istrm(coords.c_str());
  int beg,end;
  istrm>>beg>>end;

  const string db_file = argv[5];
  const string output_file = argv[6];
  try 
    {
      fasta ffile(db_file);

      const fasta::const_iterator iter = ffile.find_header(db_header);
      if( iter == ffile.end() ) {
	cout<<"Unable to find header: "<<db_header<<" in file: "<<db_file<<endl;
	return 0;
      } else {
	const fasta_seq& fs = **iter;
	const string& seq = fs.get_seq();
	string* retStr = new string(seq.substr(beg-1,(end-beg)+1));

	fasta_seq output;
	output.set_seq(retStr);
	output.set_header(header);
	output.write(output_file);
      }
      
    }
  catch(const std::runtime_error& err) 
    {
      cerr<<err.what()<<endl;
    }
  catch(...) 
    {
    }
  return 0;
}

void
usage(const string& str) {
  cout<<str<<" usage: "<<endl;
  cout<<str<<" query_header db_header begCoord endCoord db_file output_file"<<endl;
}
