// Bit Character Traits for use by standard string and iostream -*- C++ -*-

// This file is a modification of of the GNU ISO C++ Library. char_traits 
// Double check licensing restrictions (should be ok)

/** @file bit_char_traits.h
 *  This is an internal header file, included by other library headers.
 *  You should not attempt to use it directly.
 */

#ifndef _BIT_CHAR_TRAITS_H
#define _BIT_CHAR_TRAITS_H

#include <bitset>
#include <bits/fpos.h> 		// For streampos
#include <cassert>

namespace std 
{


/**
 * @brief bitset<NB> specialization of char_traits
 */
  template<size_t NB>
    struct char_traits<bitset<NB> >
    {
      typedef bitset<NB> 	char_type;
      typedef std::size_t       int_type;
      typedef streampos 	pos_type;
      typedef streamoff 	off_type;
      typedef mbstate_t 	state_type;

      static void 
      assign(char_type& __c1, const char_type& __c2)
      { __c1 = __c2; }

      static bool 
      eq(const char_type& __c1, const char_type& __c2)
      { return __c1.to_ulong() == __c2.to_ulong(); }

      static bool 
      lt(const char_type& __c1, const char_type& __c2)
      { return __c1.to_ulong() < __c2.to_ulong(); }

      static int 
      compare(const char_type* __s1, const char_type* __s2, size_t __n)
      { 
	const char_type *su1, *su2;
        int res = 0;

        for( su1 = __s1, su2 = __s2; 0 < __n; ++su1, ++su2, __n--)
                if ((res = su1->to_ulong() - su2->to_ulong()) != 0)
                        break;
        return res;

      }

      static size_t
      length(const char_type* __s)
      { 
	assert(0); return 0;
#if 0
	const char_type* sc;

        for (sc = s; *sc != '\0'; ++sc)
                /* nothing */;
        return sc - s;
	return strlen(__s); 
#endif
      }

      static const char_type* 
      find(const char_type* __s, size_t __n, const char_type& __a)
      { 
        const char_type* p = __s;
        while (__n-- ) {
	  if (eq(__c,*p++)) {
	    return (p-1);
	  }
        }
        return NULL;
      }

	//assert(0); return static_cast<const char_type*>(memchr(__s, __a, __n)); }

      static char_type* 
      move(char_type* __s1, const char_type* __s2, size_t __n)
      { assert(0); return NULL; }
      //return static_cast<char_type*>(memmove(__s1, __s2, __n)); }

      static char_type* 
      copy(char_type* __s1, const char_type* __s2, size_t __n)
      {  
	while(__n--) {
	  *__s1 = *__s2;
	  ++__s1;
	  ++__s2;
	}
	return __s1;
      }

      static char_type* 
      assign(char_type* __s, size_t __n, char_type __a) {
	while(__n--)
	  *(__s)++ = __a;
	return __s;
      }

      static char_type 
      to_char_type(const int_type& __c)
      { return static_cast<char_type>(__c); }

      // To keep both the byte 0xff and the eof symbol 0xffffffff
      // from ending up as 0xffffffff.
      static int_type 
      to_int_type(const char_type& __c)
      { return static_cast<int_type>(__c.to_ulong()); }

      static bool 
      eq_int_type(const int_type& __c1, const int_type& __c2)
      { return __c1 == __c2; }

      static int_type 
      eof() { return static_cast<int_type>(EOF); }

      static int_type 
      not_eof(const int_type& __c)
      { return (__c == eof()) ? 0 : __c; }
  };


} // namespace std

#endif
