/**
 * @file bit_string.h
 *
 * right now this is an interface file.
 * @brief Typedefs for available <i>basic_string</i> implementations
 * 
 */

/**
 * @defgroup bio_string String Module
 * @{
 * @}
 **/ 
#ifndef _BIT_STRING_H
#define _BIT_STRING_H

#include <bitset>
#include "bio_bit_traits.h" // defines nucleic acid traits
#include "ci_char_traits.h" // case insensitive char traits


/*
 * @namespace bioinfo
 * @brief namespace for the A Simple Bioinformatics C++ Toolkit
 *
 */
namespace bioinfo
{

  /** nmer_string
   * @brief represents a string as a series of overlapping nmers
	* @ingroup bio_string
   *
   * An nmer refers to a nucleotide sequence of length n
   * @see also na_nmer_overlap
   */
  template<size_t NB>
  struct nmer_string {
    typedef std::basic_string<std::bitset<NB>, na_nmer_overlap<NB> > string;
  };
  /** @ingroup bio_string  */
  /** @{ */
  /** 
   * case insensitive string
   */
  typedef std::basic_string<char, ci_char_traits> ci_string;
  /** @} */



} // _BIT_STRING_H
#endif // _BIT_STRING_H
